@@ -1,6 +1,6 @@
-package Pod::Elemental::Autoblank;
+package Pod::Elemental::Autoblank 0.103006;
 # ABSTRACT: a paragraph that always displays an extra blank line in Pod form
-$Pod::Elemental::Autoblank::VERSION = '0.103005';
+
 use namespace::autoclean;
 use Moose::Role;
 
@@ -34,7 +34,7 @@ Pod::Elemental::Autoblank - a paragraph that always displays an extra blank line
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -44,13 +44,23 @@ newline to the normally generated response to the C<as_pod_string> method.
 
 That's it!
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
