@@ -1,6 +1,6 @@
-package Pod::Elemental::Autochomp;
+package Pod::Elemental::Autochomp 0.103006;
 # ABSTRACT: a paragraph that chomps set content
-$Pod::Elemental::Autochomp::VERSION = '0.103005';
+
 use namespace::autoclean;
 use Moose::Role;
 
@@ -32,20 +32,30 @@ Pod::Elemental::Autochomp - a paragraph that chomps set content
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
 This role exists primarily to simplify elements produced by the Pod5
 transformer.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
