@@ -1,6 +1,6 @@
-package Pod::Elemental::Element::Generic::Blank;
+package Pod::Elemental::Element::Generic::Blank 0.103006;
 # ABSTRACT: a series of blank lines
-$Pod::Elemental::Element::Generic::Blank::VERSION = '0.103003';
+
 use Moose;
 with 'Pod::Elemental::Flat';
 
@@ -33,7 +33,7 @@ Pod::Elemental::Element::Generic::Blank - a series of blank lines
 
 =head1 VERSION
 
-version 0.103003
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -42,13 +42,23 @@ the most part, these are meant to be placeholders until made unnecessary by the
 Pod5 transformer.  Most end-users will never need to worry about these
 elements.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
