@@ -1,6 +1,6 @@
-package Pod::Elemental::Element::Generic::Command;
+package Pod::Elemental::Element::Generic::Command 0.103006;
 # ABSTRACT: a Pod =command element
-$Pod::Elemental::Element::Generic::Command::VERSION = '0.103003';
+
 use Moose;
 
 use namespace::autoclean;
@@ -41,7 +41,7 @@ Pod::Elemental::Element::Generic::Command - a Pod =command element
 
 =head1 VERSION
 
-version 0.103003
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -49,6 +49,16 @@ Generic::Command elements are paragraph elements implementing the
 Pod::Elemental::Command role.  They provide the command method by implementing
 a read/write command attribute.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 command
@@ -57,11 +67,11 @@ This attribute contains the name of the command, like C<head1> or C<encoding>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
