@@ -1,6 +1,6 @@
-package Pod::Elemental::Element::Pod5::Data;
+package Pod::Elemental::Element::Pod5::Data 0.103006;
 # ABSTRACT: a Pod data paragraph
-$Pod::Elemental::Element::Pod5::Data::VERSION = '0.103005';
+
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Text';
 
@@ -31,7 +31,7 @@ Pod::Elemental::Element::Pod5::Data - a Pod data paragraph
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -40,13 +40,23 @@ L<Pod5::Region|Pod::Elemental::Element::Pod5::Region> paragraphs when the
 region is not a Pod-like region.  These regions should generally have a single
 data element contained in them.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
