@@ -1,6 +1,6 @@
-package Pod::Elemental::Element::Pod5::Region;
+package Pod::Elemental::Element::Pod5::Region 0.103006;
 # ABSTRACT: a region of Pod (this role likely to be removed)
-$Pod::Elemental::Element::Pod5::Region::VERSION = '0.103005';
+
 use Moose;
 with qw(
   Pod::Elemental::Paragraph
@@ -170,7 +170,7 @@ Pod::Elemental::Element::Pod5::Region - a region of Pod (this role likely to be
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -181,6 +181,16 @@ as child paragraphs.
 Its C<as_pod_string> method will emit either a C<=begin/=end>-enclosed string
 or a C<=for> command, based on whichever is permissible.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 format_name
@@ -210,11 +220,11 @@ L<Pod::Elemental::Element::Nested>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
