@@ -1,6 +1,6 @@
-package Pod::Elemental::Node;
+package Pod::Elemental::Node 0.103006;
 # ABSTRACT: a thing with Pod::Elemental::Nodes as children
-$Pod::Elemental::Node::VERSION = '0.103005';
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -59,7 +59,7 @@ Pod::Elemental::Node - a thing with Pod::Elemental::Nodes as children
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -67,6 +67,16 @@ Classes that include Pod::Elemental::Node represent collections of child
 Pod::Elemental::Paragraphs.  This includes Pod documents, Pod5 regions, and
 nested Pod elements produced by the Gatherer transformer.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 children
@@ -77,11 +87,11 @@ elements contained by an object.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
