@@ -1,6 +1,6 @@
-package Pod::Elemental::Paragraph;
+package Pod::Elemental::Paragraph 0.103006;
 # ABSTRACT: a paragraph in a Pod document
-$Pod::Elemental::Paragraph::VERSION = '0.103004';
+
 use namespace::autoclean;
 use Moose::Role;
 
@@ -83,7 +83,7 @@ Pod::Elemental::Paragraph - a paragraph in a Pod document
 
 =head1 VERSION
 
-version 0.103004
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -92,6 +92,16 @@ Classes including this role represent paragraphs in a Pod document.  The
 paragraph is the fundamental unit of dividing up Pod documents, so this is a
 often-included role.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 content
@@ -125,11 +135,11 @@ document.  Its exact output is likely to change over time.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
