@@ -1,6 +1,6 @@
-package Pod::Elemental::Transformer;
+package Pod::Elemental::Transformer 0.103006;
 # ABSTRACT: something that transforms a node tree into a new tree
-$Pod::Elemental::Transformer::VERSION = '0.103005';
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -39,7 +39,7 @@ Pod::Elemental::Transformer - something that transforms a node tree into a new t
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -50,6 +50,16 @@ rewriters.
 
 A class including this role must implement the following methods:
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 transform_node
@@ -61,11 +71,11 @@ the limit.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
