@@ -1,6 +1,6 @@
-package Pod::Elemental::Transformer::Nester;
+package Pod::Elemental::Transformer::Nester 0.103006;
 # ABSTRACT: group the document into sections
-$Pod::Elemental::Transformer::Nester::VERSION = '0.103003';
+
 use Moose;
 with 'Pod::Elemental::Transformer';
 
@@ -159,7 +159,7 @@ Pod::Elemental::Transformer::Nester - group the document into sections
 
 =head1 VERSION
 
-version 0.103003
+version 0.103006
 
 =head1 OVERVIEW
 
@@ -206,6 +206,16 @@ The nester will convert its structure to look like this:
 Once an element is reached that does not pass the content selectors, the
 nesting ceases until the next potential container.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 top_selector
@@ -222,11 +232,11 @@ top-level container may be moved under the container.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
