@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Pod::Elemental::Types;
+package Pod::Elemental::Types 0.103006;
 # ABSTRACT: data types for Pod::Elemental
-$Pod::Elemental::Types::VERSION = '0.103005';
+
 use MooseX::Types -declare => [ qw(FormatName ChompedString) ];
 use MooseX::Types::Moose qw(Str);
 
@@ -46,12 +46,22 @@ Pod::Elemental::Types - data types for Pod::Elemental
 
 =head1 VERSION
 
-version 0.103005
+version 0.103006
 
 =head1 OVERVIEW
 
 This is a library of MooseX::Types types used by Pod::Elemental.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 TYPES
 
 =head2 FormatName
@@ -66,11 +76,11 @@ Str ending in a single newline -- the newline is dropped.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
